@@ -137,7 +137,7 @@ class Experiment:
                 collected outside this analysis window.
             analysis_length_days (int): the length of the analysis window,
                 measured in days.
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
+            enrollments_query_type ('normandy', 'glean-event' or 'fenix-fallback'):
                 Specifies the query type to use to get the experiment's
                 enrollments, unless overridden by
                 ``custom_enrollments_query``.
@@ -206,9 +206,7 @@ class Experiment:
             )
         )
 
-        bq_context.run_query(
-            enrollments_sql, enrollments_table_name
-        )
+        bq_context.run_query(enrollments_sql, enrollments_table_name)
 
         metrics_sql = self.build_metrics_query(
             metric_list=metric_list,
@@ -222,9 +220,7 @@ class Experiment:
             "_".join([last_date_full_data, self.experiment_slug, hash_ish(metrics_sql)])
         )
 
-        return bq_context.run_query(
-            metrics_sql, full_res_table_name
-        ).to_dataframe()
+        return bq_context.run_query(metrics_sql, full_res_table_name).to_dataframe()
 
     def get_time_series_data(
         self,
@@ -251,7 +247,7 @@ class Experiment:
                 experiment recipe was deactivated), then do that here.
             time_series_period ('daily' or 'weekly'): How long each
                 analysis window should be.
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
+            enrollments_query_type ('normandy', 'glean-event' or 'fenix-fallback'):
                 Specifies the query type to use to get the experiment's
                 enrollments, unless overridden by
                 ``custom_enrollments_query``.
@@ -317,9 +313,7 @@ class Experiment:
             )
         )
 
-        bq_context.run_query(
-            enrollments_sql, enrollments_table_name
-        )
+        bq_context.run_query(enrollments_sql, enrollments_table_name)
 
         metrics_sql = self.build_metrics_query(
             metric_list=metric_list,
@@ -354,7 +348,7 @@ class Experiment:
         Args:
             time_limits (TimeLimits): An object describing the
                 interval(s) to query
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
+            enrollments_query_type ('normandy', 'glean-event' or 'fenix-fallback'):
                 Specifies the query type to use to get the experiment's
                 enrollments, unless overridden by
                 ``custom_enrollments_query``.
@@ -464,6 +458,12 @@ class Experiment:
         """Return SQL to query a list of enrollments and their branches"""
         if enrollments_query_type == "normandy":
             return self._build_enrollments_query_normandy(time_limits)
+        elif enrollments_query_type == "glean-event":
+            if not self.app_id:
+                raise ValueError(
+                    "App ID must be defined for building Glean enrollments query"
+                )
+            return self._build_enrollments_query_glean_event(time_limits, self.app_id)
         elif enrollments_query_type == "fenix-fallback":
             return self._build_enrollments_query_fenix_baseline(time_limits)
         else:
@@ -495,7 +495,6 @@ class Experiment:
 
     def _build_enrollments_query_fenix_baseline(self, time_limits):
         """Return SQL to query enrollments for a Fenix no-event experiment
-
         If enrollment events are available for this experiment, then you
         can take a better approach than this method. But in the absence
         of enrollment events (e.g. in a Mako-based experiment, which
@@ -531,6 +530,39 @@ class Experiment:
             dataset=self.app_id or "org_mozilla_firefox",
         )
 
+    def _build_enrollments_query_glean_event(self, time_limits, dataset):
+        """Return SQL to query enrollments for a Glean no-event experiment
+
+        If enrollment events are available for this experiment, then you
+        can take a better approach than this method. But in the absence
+        of enrollment events (e.g. in a Mako-based experiment, which
+        does not send enrollment events), you need to fall back to using
+        ``ping_info.experiments`` to get a list of who is in what branch
+        and when they enrolled.
+        """
+        return """
+            SELECT events.client_info.client_id AS client_id,
+                mozfun.map.get_key(
+                    e.extra,
+                    'branch'
+                ) AS branch,
+                DATE(MIN(events.submission_timestamp)) AS enrollment_date
+            FROM `moz-fx-data-shared-prod.{dataset}.events` events,
+            UNNEST(events.events) AS e
+            WHERE
+                DATE(events.submission_timestamp)
+                BETWEEN '{first_enrollment_date}' AND '{last_enrollment_date}'
+                AND e.category = "nimbus_events"
+                AND mozfun.map.get_key(e.extra, "experiment") = '{experiment_slug}'
+                AND e.name = 'enrollment'
+            GROUP BY client_id, branch
+            """.format(
+            experiment_slug=self.experiment_slug,
+            first_enrollment_date=time_limits.first_enrollment_date,
+            last_enrollment_date=time_limits.last_enrollment_date,
+            dataset=self.app_id or dataset,
+        )
+
     def _build_metrics_query_bits(self, metric_list, time_limits):
         """Return lists of SQL fragments corresponding to metrics."""
         ds_metrics = self._partition_by_data_source(metric_list)
@@ -763,11 +795,7 @@ class TimeLimits:
                 enrollments. This is a mandatory argument because it
                 determines the number of points in the time series.
         """
-        period_duration = {
-            "daily": 1,
-            "weekly": 7,
-            "28_day": 28
-        }
+        period_duration = {"daily": 1, "weekly": 7, "28_day": 28}
 
         if time_series_period not in period_duration:
             raise ValueError(
