@@ -3,10 +3,7 @@ import pytest
 from mozanalysis.metrics import DataSource
 
 
-@pytest.mark.parametrize(
-    "experiments_column_type",
-    [None, "simple", "native"]
-)
+@pytest.mark.parametrize("experiments_column_type", [None, "simple", "native"])
 def test_datasource_constructor_succeeds(experiments_column_type):
     DataSource(
         name="foo",
@@ -21,7 +18,7 @@ def test_datasource_constructor_succeeds(experiments_column_type):
         (None, "mytable", "simple", TypeError),
         ("name", None, "simple", TypeError),
         ("name", "mytable", "wrong", ValueError),
-    ]
+    ],
 )
 def test_datasource_constructor_fails(name, from_expr, experiments_column_type, error):
     with pytest.raises(error):
@@ -30,3 +27,16 @@ def test_datasource_constructor_fails(name, from_expr, experiments_column_type,
             from_expr=from_expr,
             experiments_column_type=experiments_column_type,
         )
+
+
+def test_complains_about_template_without_default():
+    with pytest.raises(ValueError):
+        DataSource(
+            name="foo",
+            from_expr="moz-fx-data-shared-prod.{dataset}.foo",
+        )
+    DataSource(
+        name="foo",
+        from_expr="moz-fx-data-shared-prod.{dataset}.foo",
+        default_dataset="dataset",
+    )
